Crate four_letter_phat_rs

Crate four_letter_phat_rs 

four-letter-phat-rs

four-letter-phat-rs is a Rust driver for I2C alphanumeric displays consisting of 4 14-segment displays driven by a HT16K33 LED controller. Examples of these are the Pimoroni Four Letter pHAT and the Adafruit Quad Alphanumeric Display Backpack.

It is agnostic to the underlying I2C device used to interface with the display, and works in no_std environments without an allocator.

Structs

Dimming
Display dimming.
Display
The LED display state.
FourLetterPhat
A board with 4 14-segment displays and a HT16K33 driver

Enums

PhatError
An error encountered when writing to the Four Letter pHAT